//chemesis2
include rest-xodus.g

//effect of concentration change on resting potential.  Units are mM

/*initial (default) concentrations*/
float Kin0 = 90
float Kout0 = 2.5
float clout0 = 120
float clin0 = 3.3

float PI	= 3.14159

/*cell parameters*/
float diameter = 50e-4 /* units are cm, thus value is 50 microns */
float surface = PI*{diameter}*{diameter}
float volume = {surface}*{diameter}/6/1000	/* 1000 converts from cc to L*/
float RM = 20.0	/* megaohm-cm^2 */
float CM = 1e3  /* nanoFarad/cm^2 */

/*parameters of extracellular space*/
float eclen = 0.1	/* 1 mm */
float ecdiam = 1.0
float ecarea = PI*{ecdiam}*{eclen}
float ecvol = {ecarea}*{ecdiam}/1000	/* convert cc to L */

create neutral cell
ce cell

/* concentration compartments*/
create rxnpool kin 
setfield kin radius {diameter/2} \
	vol {volume} \
	SAout {surface}  \
	Cinit {Kin0} \
    Iunits 1e-9 \
    units 1e-3

create rxnpool clin 
setfield clin radius {diameter/2} \
	vol {volume} \
	SAout {surface}  \
	Cinit {clin0}  \
    Iunits 1e-9 \
    units 1e-3

create rxnpool kout	
setfield kout radius {ecdiam/2}	\
	vol {ecvol}	\
	SAout {ecarea}	\
	SAin {surface}	\
	len {eclen}	\
	Cinit {Kout0}  \
    Iunits 1e-9 \
    units 1e-3

create rxnpool clout     
setfield clout radius {ecdiam/2}       \
	vol {ecvol}     \
	SAout {ecarea}  \
	SAin {surface}  \
	len {eclen}     \
	Cinit {clout0} \
    Iunits 1e-9 \
    units 1e-3

/* voltage compartment*/
create compartment vm 
setfield vm Rm {RM*1000/surface} Cm {CM*surface} dia {diameter} Em -90

/* potassium and chloride channels*/
create nernst krev 
setfield krev scale 1e3 T 20 valency 1
create vdep_channel kchan
setfield kchan gbar {30.0*surface}
create nernst clrev 
setfield clrev scale 1e3 T 20 valency -1
create vdep_channel clchan 
setfield clchan gbar {18.0*surface}	/* microsiemens /cm^2 */

/* or could use ghk object instead:
create ghk kperm p {some value}
create ghk clperm p {some value}
addmsg kin kperm CIN Conc
addmsg kout kperm COUT Conc
addmsg vm kperm VOLTAGE Vm
addmsg kperm vm CHANNEL Ek Gk
addmsg clin clperm CIN Conc
addmsg clout clperm COUT Conc
addmsg vm clperm VOLTAGE Vm
addmsg clperm vm CHANNEL Ek Gk

current must be in units of nanoamps:
addmsg kperm kin CURRENT 1 Ik
addmsg kperm kout CURRENT -1 Ik
addmsg clperm clin CURRENT -1 Ik
addmsg clperm clout CURRENT 1 Ik
*/

/*messages between compartments*/
addmsg kin krev CIN Conc
addmsg kout krev COUT Conc
addmsg clin clrev CIN Conc
addmsg clout clrev COUT Conc
addmsg vm kchan VOLTAGE Vm
addmsg vm clchan VOLTAGE Vm
addmsg krev kchan EK E
addmsg clrev clchan EK E
addmsg kchan vm CHANNEL Gk Ek
addmsg clchan vm CHANNEL Gk Ek

//current must be in units of nanoamps: 
/* need to define charge as negative of actual charge because of interaction
 between vdep_channel and rxnpool */
addmsg kchan kin CURRENT -1 Ik
addmsg kchan kout CURRENT 1 Ik
addmsg clchan clin CURRENT 1 Ik
addmsg clchan clout CURRENT -1 Ik 

make_graphs
make_control

setclock 0 1.0
reset
